@@ -40,35 +40,24 @@
 #include <QByteArray>
 #include <QDate>
 
-namespace KCalCore
-{
-template <typename T> class SortableList;
+namespace KCalCore {
+template<typename T> class SortableList;
 typedef SortableList<QDate> DateList;
 }
 
-namespace KHolidays
-{
-class HolidayRegion;
-typedef QSharedPointer<HolidayRegion> HolidayRegionPtr;
-}
-
-namespace CalendarSupport
-{
+namespace CalendarSupport {
 class CollectionSelection;
 class KCalPrefs;
 }
 
-namespace Akonadi
-{
+namespace Akonadi {
 class IncidenceChanger;
 }
 
 class KCheckableProxyModel;
 class KConfigGroup;
 
-namespace EventViews
-{
-
+namespace EventViews {
 enum {
     BUSY_BACKGROUND_ALPHA = 70
 };
@@ -133,7 +122,7 @@ public:
      *        will be retrieved for display.
      * @param parent is the parent QWidget.
      */
-    explicit EventView(QWidget *parent = Q_NULLPTR);
+    explicit EventView(QWidget *parent = nullptr);
 
     /**
      * Destructor. Views will do view-specific cleanups here.
@@ -144,8 +133,9 @@ public:
 
     /**
       Return calendar object of this view.
-      TODO: replace with a version that returns a KCalcCore::Calendar to be able to use it in different enviroments
-           see agendaview for example calendar2(incidence)
+      TODO: replace with a version that returns a KCalCore::Calendar so it
+            can be used in different environments.
+            see agendaview for example calendar2(incidence)
     */
     virtual Akonadi::ETMCalendar::Ptr calendar() const;
 
@@ -153,10 +143,10 @@ public:
       update config is called after prefs are set.
     */
     virtual void setPreferences(const PrefsPtr &preferences);
-    PrefsPtr preferences() const;
+    Q_REQUIRED_RESULT PrefsPtr preferences() const;
 
     virtual void setKCalPreferences(const KCalPrefsPtr &preferences);
-    KCalPrefsPtr kcalPreferences() const;
+    Q_REQUIRED_RESULT KCalPrefsPtr kcalPreferences() const;
 
     /**
       @return a list of selected events. Most views can probably only
@@ -184,13 +174,19 @@ public:
      */
     virtual QDateTime selectionEnd() const;
 
+    /**
+      Sets the default start/end date/time for new events.
+      Return true if anything was changed
+    */
+    virtual bool eventDurationHint(QDateTime &startDt, QDateTime &endDt, bool &allDay) const;
+
     /**
       Returns whether or not date range selection is enabled. This setting only
       applies to views that actually supports selecting cells.
       @see selectionStart()
       @see selectionEnd()
      */
-    bool dateRangeSelectionEnabled() const;
+    Q_REQUIRED_RESULT bool dateRangeSelectionEnabled() const;
 
     /**
       Enable or disable date range selection.
@@ -214,7 +210,7 @@ public:
 
     virtual void showConfigurationDialog(QWidget *parent);
 
-    QByteArray identifier() const;
+    Q_REQUIRED_RESULT QByteArray identifier() const;
     void setIdentifier(const QByteArray &identifier);
 
     /**
@@ -241,7 +237,7 @@ public:
       each AgendaView displays only one collection.
     */
     void setCollectionId(Akonadi::Collection::Id id);
-    Akonadi::Collection::Id collectionId() const;
+    Q_REQUIRED_RESULT Akonadi::Collection::Id collectionId() const;
 
     //----------------------------------------------------------------------------
     KCheckableProxyModel *takeCustomCollectionSelectionProxyModel();
@@ -266,21 +262,20 @@ public:
      * month to show when the week crosses months.  It's a QDate instead
      * of uint so it can be easily fed to KCalendarSystem's functions.
      */
-    virtual void setDateRange(const KDateTime &start, const KDateTime &end,
-                              const QDate &preferredMonth = QDate());
+    virtual void setDateRange(const QDateTime &start, const QDateTime &end, const QDate &preferredMonth = QDate());
 
-    KDateTime startDateTime() const;
-    KDateTime endDateTime() const;
+    Q_REQUIRED_RESULT QDateTime startDateTime() const;
+    Q_REQUIRED_RESULT QDateTime endDateTime() const;
 
-    KDateTime actualStartDateTime() const;
-    KDateTime actualEndDateTime() const;
+    Q_REQUIRED_RESULT QDateTime actualStartDateTime() const;
+    Q_REQUIRED_RESULT QDateTime actualEndDateTime() const;
 
-    int showMoveRecurDialog(const KCalCore::Incidence::Ptr &incidence, const QDate &date);
+    Q_REQUIRED_RESULT int showMoveRecurDialog(const KCalCore::Incidence::Ptr &incidence, const QDate &date);
 
     /**
       Handles key events, opens the new event dialog when enter is pressed, activates type ahead.
     */
-    bool processKeyEvent(QKeyEvent *);
+    Q_REQUIRED_RESULT bool processKeyEvent(QKeyEvent *);
 
     /*
      * Sets the QObject that will receive key events that were made
@@ -303,15 +298,15 @@ public:
     /**
       Returns if there are pending changes and a redraw is needed.
     */
-    Changes changes() const;
+    Q_REQUIRED_RESULT Changes changes() const;
 
     /**
      * Returns a variation of @p color that will be used for the border
      * of an agenda or month item.
      */
-    static QColor itemFrameColor(const QColor &color, bool selected);
+    Q_REQUIRED_RESULT static QColor itemFrameColor(const QColor &color, bool selected);
 
-    QString iconForItem(const Akonadi::Item &);
+    Q_REQUIRED_RESULT QString iconForItem(const Akonadi::Item &);
 
 public Q_SLOTS:
     /**
@@ -321,8 +316,7 @@ public Q_SLOTS:
       @param incidenceList a list of incidences to show.
       @param date is the QDate on which the incidences are being shown.
     */
-    virtual void showIncidences(const Akonadi::Item::List &incidenceList,
-                                const QDate &date) = 0;
+    virtual void showIncidences(const Akonadi::Item::List &incidenceList, const QDate &date) = 0;
 
     /**
       Updates the current display to reflect changes that may have happened
@@ -352,12 +346,6 @@ public Q_SLOTS:
     */
     virtual void clearSelection();
 
-    /**
-      Sets the default start/end date/time for new events.
-      Return true if anything was changed
-    */
-    virtual bool eventDurationHint(QDateTime &startDt, QDateTime &endDt, bool &allDay) const;
-
     void focusChanged(QWidget *, QWidget *);
 
     /**
@@ -367,10 +355,10 @@ public Q_SLOTS:
     void defaultAction(const Akonadi::Item &incidence);
 
     /**
-       Set which holidays the user wants to use.
-       @param holidayRegion a HolidayRegion object initialized with the desired locale.
+       Set which holiday regions the user wants to use.
+       @param regions a list of Holiday Regions strings.
     */
-    void setHolidayRegion(const KHolidays::HolidayRegionPtr &holidayRegion);
+    void setHolidayRegions(const QStringList &regions);
 
 Q_SIGNALS:
     /**
@@ -502,8 +490,7 @@ protected:
     /**
       @deprecated
      */
-    virtual void showDates(const QDate &start, const QDate &end,
-                           const QDate &preferredMonth = QDate()) = 0;
+    virtual void showDates(const QDate &start, const QDate &end, const QDate &preferredMonth = QDate()) = 0;
 
     /**
      * from the requested date range (passed via setDateRange()), calculates the
@@ -515,8 +502,8 @@ protected:
      * month to show when the week crosses months.  It's a QDate instead of
      * uint so it can be easily fed to KCalendarSystem's functions.
      */
-    virtual QPair<KDateTime, KDateTime> actualDateRange(
-        const KDateTime &start, const KDateTime &end, const QDate &preferredMonth = QDate()) const;
+    virtual QPair<QDateTime, QDateTime> actualDateRange(
+        const QDateTime &start, const QDateTime &end, const QDate &preferredMonth = QDate()) const;
     /*
     virtual void incidencesAdded( const Akonadi::Item::List &incidences );
     virtual void incidencesAboutToBeRemoved( const Akonadi::Item::List &incidences );
@@ -528,7 +515,6 @@ private:
     EventViewPrivate *const d_ptr;
     Q_DECLARE_PRIVATE(EventView)
 };
-
 }
 
 #endif
